def neural_network():
    code = """
    import numpy as np
    from Mentera.activation_functions import sigmoid, tanh, relu, lrelu, softmax
    
    def initialize_parameters(n_x, n_h, n_y):
        np.random.seed(2)

        W1 = np.random.randn(n_h, n_x) * 0.01
        b1 = np.zeros((n_h, 1))
        W2 = np.random.randn(n_y, n_h) * 0.01
        b2 = np.zeros((n_y, 1))

        parameters = {"W1": W1, "b1": b1, "W2": W2, "b2": b2}
   
        return parameters

    def forward_propagation(X, parameters):
        W1 = parameters["W1"]
        b1 = parameters["b1"]
        W2 = parameters["W2"]
        b2 = parameters["b2"]

        Z1 = np.dot(W1, X) + b1
        A1 = tanh(Z1)
        Z2 = np.dot(W2, A1) + b2
        A2 = sigmoid(Z2)

        cache = {"Z1": Z1, "A1": A1, "Z2": Z2, "A2": A2}
    
        return A2, cache

    def compute_cost(A2, Y):
        m = Y.shape[1]
        logprobs = np.multiply(np.log(A2), Y) + np.multiply(np.log(1 - A2), (1 - Y))
        cost = -np.sum(logprobs) / m
        cost = float(np.squeeze(cost))
        return cost

    def backward_propagation(parameters, cache, X, Y):
        W1 = parameters["W1"]
        b1 = parameters["b1"]
        W2 = parameters["W2"]
        b2 = parameters["b2"]

        A1 = cache["A1"]
        A2 = cache["A2"]

        m = Y.size
        dZ2 = A2 - Y
        dW2 = np.dot(dZ2, A1.T) / m
        db2 = np.sum(dZ2, axis=1, keepdims=True) / m
        dA1 = np.dot(W2.T, dZ2)
        dZ1 = dA1 * (1 - np.power(A1, 2))
        dW1 = np.dot(dZ1, X.T) / m
        db1 = np.sum(dZ1, axis=1, keepdims=True) / m

        gradients = {"dW2": dW2, "db2": db2, "dW1": dW1, "db1": db1}
        return gradients

    def update_parameters(parameters, gradients, lr=0.01):
        W1 = parameters["W1"]
        b1 = parameters["b1"]
        W2 = parameters["W2"]
        b2 = parameters["b2"]

        dW1 = gradients["dW1"]
        db1 = gradients["db1"]
        dW2 = gradients["dW2"]
        db2 = gradients["db2"]

        W1 = W1 - lr * dW1
        b1 = b1 - lr * db1
        W2 = W2 - lr * dW2
        b2 = b2 - lr * db2

        parameters = {"W1": W1, "b1": b1, "W2": W2, "b2": b2}

        return parameters

    def neural_network(X, Y, layers, itr=10000, print_cost=False):
        np.random.seed(3)
        n_x = X.shape[0]
        n_y = Y.shape[0]
        n_h = layers

        parameters = initialize_parameters(n_x, n_h, n_y)

        for i in range(0, itr):
            A2, cache = forward_propagation(X, parameters)
            cost = compute_cost(A2, Y)
            gradients = backward_propagation(parameters, cache, X, Y)
            parameters = update_parameters(parameters, gradients, lr=0.01)

            if print_cost and i % 100 == 0:
                print("cost % i:%f" % (i, cost))

            return parameters
    """
    print(code)
